@@ -6,7 +6,6 @@ use strict;
 use Class::ReturnValue;
 use vars qw($VERSION @ISA %DBIHandle $PrevHandle $DEBUG $TRANSDEPTH);
 
-
 $TRANSDEPTH = 0;
 
 $VERSION = '$Version$';
@@ -22,24 +21,16 @@ DBIx::SearchBuilder::Handle - Perl extension which is a generic DBI handle
 
   use DBIx::SearchBuilder::Handle;
 
- my $Handle = DBIx::SearchBuilder::Handle->new();
- $Handle->Connect( Driver => 'mysql',
-		   Database => 'dbname',
-		   Host => 'hostname',
-		   User => 'dbuser',
-		   Password => 'dbpassword');
+  my $handle = DBIx::SearchBuilder::Handle->new();
+  $handle->Connect( Driver => 'mysql',
+                    Database => 'dbname',
+                    Host => 'hostname',
+                    User => 'dbuser',
+                    Password => 'dbpassword');
  
- 
-
 =head1 DESCRIPTION
 
-Jesse's a slacker.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-Jesse Vincent, jesse@fsck.com
+This class provides a wrapper for DBI handles that can also perform a number of additional functions.
  
 =cut
 
@@ -65,35 +56,6 @@ sub new  {
 
 # }}}
 
-# {{{ sub Insert
-=head2 Insert $TABLE_NAME @KEY_VALUE_PAIRS
-
-Takes a table name and a set of key-value pairs in an array. splits the key value pairs, constructs an INSERT statement and performs the insert. Returns the row_id of this row.
-
-=cut
-
-sub Insert {
-  my($self, $table, @pairs) = @_;
-  my(@cols, @vals, @bind);
-
-#  my %seen; #only the *first* value is used - allows drivers to specify default
-  while ( my $key = shift @pairs ) {
-    my $value = shift @pairs;
-    #    next if $seen{$key}++;
-    push @cols, $key;
-    push @vals, '?';
-    push @bind, $value;  
-  }
-
-  my $QueryString =
-    "INSERT INTO $table (". join(", ", @cols). ") VALUES ".
-    "(". join(", ", @vals). ")";
-
-    my $sth =  $self->SimpleQuery($QueryString, @bind);
-    return ($sth);
-  }
-# }}}
-
 # {{{ sub Connect 
 
 =head2 Connect PARAMHASH: Driver, Database, Host, User, Password
@@ -358,6 +320,35 @@ sub dbh {
 
 # }}}
 
+# {{{ sub Insert
+=head2 Insert $TABLE_NAME @KEY_VALUE_PAIRS
+
+Takes a table name and a set of key-value pairs in an array. splits the key value pairs, constructs an INSERT statement and performs the insert. Returns the row_id of this row.
+
+=cut
+
+sub Insert {
+  my($self, $table, @pairs) = @_;
+  my(@cols, @vals, @bind);
+
+  #my %seen; #only the *first* value is used - allows drivers to specify default
+  while ( my $key = shift @pairs ) {
+    my $value = shift @pairs;
+    # next if $seen{$key}++;
+    push @cols, $key;
+    push @vals, '?';
+    push @bind, $value;  
+  }
+
+  my $QueryString =
+    "INSERT INTO $table (". join(", ", @cols). ") VALUES ".
+    "(". join(", ", @vals). ")";
+
+    my $sth =  $self->SimpleQuery($QueryString, @bind);
+    return ($sth);
+  }
+# }}}
+
 # {{{ sub UpdateRecordValue 
 
 =head2 UpdateRecordValue 
@@ -438,51 +429,54 @@ Execute the SQL string specified in QUERY_STRING
 
 =cut
 
-sub SimpleQuery  {
-    my $self = shift;
+sub SimpleQuery {
+    my $self        = shift;
     my $QueryString = shift;
     my @bind_values;
-   @bind_values = (@_) if (@_);;
-
-    
+    @bind_values = (@_) if (@_);
 
     my $sth = $self->dbh->prepare($QueryString);
     unless ($sth) {
-	if ($DEBUG) {
-	    die "$self couldn't prepare the query '$QueryString'" . 
-	      $self->dbh->errstr . "\n";
-	}
-	else {
-	    warn "$self couldn't prepare the query '$QueryString'" . 
-	      $self->dbh->errstr . "\n";
-        my $ret = Class::ReturnValue->new();
-        $ret->as_error( errno => '-1',
-                            message => "Couldn't prepare the query '$QueryString'.". $self->dbh->errstr,
-                            do_backtrace => undef);
-	    return ($ret->return_value);
-	}
+        if ($DEBUG) {
+            die "$self couldn't prepare the query '$QueryString'"
+              . $self->dbh->errstr . "\n";
+        }
+        else {
+            warn "$self couldn't prepare the query '$QueryString'"
+              . $self->dbh->errstr . "\n";
+            my $ret = Class::ReturnValue->new();
+            $ret->as_error(
+                errno   => '-1',
+                message => "Couldn't prepare the query '$QueryString'."
+                  . $self->dbh->errstr,
+                do_backtrace => undef
+            );
+            return ( $ret->return_value );
+        }
     }
 
-    # Check @bind_values for HASH refs 
-    for (my $bind_idx = 0; $bind_idx < scalar @bind_values; $bind_idx++) {
-        if (ref($bind_values[$bind_idx]) eq "HASH") {
+    # Check @bind_values for HASH refs
+    for ( my $bind_idx = 0 ; $bind_idx < scalar @bind_values ; $bind_idx++ ) {
+        if ( ref( $bind_values[$bind_idx] ) eq "HASH" ) {
             my $bhash = $bind_values[$bind_idx];
             $bind_values[$bind_idx] = $bhash->{'value'};
             delete $bhash->{'value'};
-            $sth->bind_param($bind_idx+1, undef, $bhash );
+            $sth->bind_param( $bind_idx + 1, undef, $bhash );
         }
     }
 
     my $basetime;
-    if ($self->LogSQLStatements) {
-        $basetime = Time::HiRes::time(); 
+    if ( $self->LogSQLStatements ) {
+        $basetime = Time::HiRes::time();
     }
     my $executed;
-    eval {     $executed =$sth->execute(@bind_values) };
+    {
+        no warnings 'uninitialized' ; # undef in bind_values makes DBI sad
+        eval { $executed = $sth->execute(@bind_values) };
+    }
+    if ( $self->LogSQLStatements ) {
+        $self->_LogSQLStatement( $QueryString, tv_interval($basetime) );
 
-    if ($self->LogSQLStatements) {
-            $self->_LogSQLStatement($QueryString ,tv_interval ( $basetime ));
- 
     }
 
     if ( $@ or !$executed ) {
@@ -494,20 +488,20 @@ sub SimpleQuery  {
         else {
             warn "$self couldn't execute the query '$QueryString'";
 
-              my $ret = Class::ReturnValue->new();
+            my $ret = Class::ReturnValue->new();
             $ret->as_error(
-                         errno   => '-1',
-                         message => "Couldn't execute the query '$QueryString'"
-                           . $self->dbh->errstr,
-                         do_backtrace => undef );
-            return ($ret->return_value);
+                errno   => '-1',
+                message => "Couldn't execute the query '$QueryString'"
+                  . $self->dbh->errstr,
+                do_backtrace => undef
+            );
+            return ( $ret->return_value );
         }
 
     }
     return ($sth);
-    
-    
-  }
+
+}
 
 # }}}
 
@@ -1058,6 +1052,10 @@ __END__
 
 # {{{ POD
 
+=head1 AUTHOR
+
+Jesse Vincent, jesse@fsck.com
+
 =head1 SEE ALSO
 
 perl(1), L<DBIx::SearchBuilder>
